/* v0.9
 *
 * nav.h:  Navigation module header.
 *
 * This program is free software and may be freely redistributed as
 * specified in the GNU General Public License.  Please see the file
 * 'COPYING' for details.   
 */

extern void navSetCourse(TAG *, int, float, float);
extern void navSetWarp(TAG *, dbref, float);
extern void navAllocCheck(TAG *);
extern void navDoorControl(TAG *, dbref, int);
extern void navLaunch(TAG *, dbref, dbref);
extern void navLand(TAG *, dbref, int);
extern void navDock(TAG *, dbref, TAG *, int);
extern void navUndock(TAG *, dbref, dbref);
extern int navWarpCost(TAG *, float);
extern void navOrbit(TAG *, dbref, int);
extern float navMaxWarp(TAG *, int);
extern void navRangeString(TAG *, range_t, char *, unsigned int);

#ifdef ENABLE_ODOMETER
extern void navSetOdometer(TAG *, int);
extern void navWriteOdometer(dbref, SHIP *);
#endif

#ifdef ENABLE_TIME_TRACKER
extern void navSetTimeActive(TAG *, time_t);
extern void navWriteTimeActive(dbref, SHIP *);
#endif

